{% extends 'djangomaster/_single_col.html' %}
{% load url from future %}

{% block page_title %}Django Master{% endblock %}

{% block content %}

    <h2 class="content-subhead">requirements.txt</h2>
    {% if object.requirements.BASE_DIR_ERROR %}
        <div>
            <small>
                Define the settings.{{settings.BASE_DIR_NAME}} variable, then it will be possible to
                locate the requirements.txt file. <br />
                Add the following in your settings.py: <br />
                <code>BASE_DIR = os.path.dirname(os.path.abspath(__file__))</code> <br />

                You can define which variable will be used by changing settings.DJANGO_MASTER_BASE_DIR.
            </small>
        </div>
    {% elif object.requirements.REQUIREMENTS_ERROR %}
        <div>
            <small>
                Could not find a file in {{object.requirements.path}}.<br />
            </small>
        </div>
    {% else %}
        <div class="pure-form">
            <textarea rows="10" readonly='readonly' style="width: 100%; resize: none">{{ object.requirements.content }}</textarea>
        </div>
    {% endif %}


{% endblock %}

