@media screen and (min-width: 35.5em) {
    .u-sm-1,
    .u-sm-1-1,
    .u-sm-1-2,
    .u-sm-1-3,
    .u-sm-2-3,
    .u-sm-1-4,
    .u-sm-3-4,
    .u-sm-1-5,
    .u-sm-2-5,
    .u-sm-3-5,
    .u-sm-4-5,
    .u-sm-5-5,
    .u-sm-1-6,
    .u-sm-5-6,
    .u-sm-1-8,
    .u-sm-3-8,
    .u-sm-5-8,
    .u-sm-7-8,
    .u-sm-1-12,
    .u-sm-5-12,
    .u-sm-7-12,
    .u-sm-11-12,
    .u-sm-1-24,
    .u-sm-2-24,
    .u-sm-3-24,
    .u-sm-4-24,
    .u-sm-5-24,
    .u-sm-6-24,
    .u-sm-7-24,
    .u-sm-8-24,
    .u-sm-9-24,
    .u-sm-10-24,
    .u-sm-11-24,
    .u-sm-12-24,
    .u-sm-13-24,
    .u-sm-14-24,
    .u-sm-15-24,
    .u-sm-16-24,
    .u-sm-17-24,
    .u-sm-18-24,
    .u-sm-19-24,
    .u-sm-20-24,
    .u-sm-21-24,
    .u-sm-22-24,
    .u-sm-23-24,
    .u-sm-24-24 {
        display: inline-block;
        *display: inline;
        zoom: 1;
        letter-spacing: normal;
        word-spacing: normal;
        vertical-align: top;
        text-rendering: auto;
    }

    .u-sm-1-24 {
        width: 4.1667%;
        *width: 4.1357%;
    }

    .u-sm-1-12,
    .u-sm-2-24 {
        width: 8.3333%;
        *width: 8.3023%;
    }

    .u-sm-1-8,
    .u-sm-3-24 {
        width: 12.5000%;
        *width: 12.4690%;
    }

    .u-sm-1-6,
    .u-sm-4-24 {
        width: 16.6667%;
        *width: 16.6357%;
    }

    .u-sm-1-5 {
        width: 20%;
        *width: 19.9690%;
    }

    .u-sm-5-24 {
        width: 20.8333%;
        *width: 20.8023%;
    }

    .u-sm-1-4,
    .u-sm-6-24 {
        width: 25%;
        *width: 24.9690%;
    }

    .u-sm-7-24 {
        width: 29.1667%;
        *width: 29.1357%;
    }

    .u-sm-1-3,
    .u-sm-8-24 {
        width: 33.3333%;
        *width: 33.3023%;
    }

    .u-sm-3-8,
    .u-sm-9-24 {
        width: 37.5000%;
        *width: 37.4690%;
    }

    .u-sm-2-5 {
        width: 40%;
        *width: 39.9690%;
    }

    .u-sm-5-12,
    .u-sm-10-24 {
        width: 41.6667%;
        *width: 41.6357%;
    }

    .u-sm-11-24 {
        width: 45.8333%;
        *width: 45.8023%;
    }

    .u-sm-1-2,
    .u-sm-12-24 {
        width: 50%;
        *width: 49.9690%;
    }

    .u-sm-13-24 {
        width: 54.1667%;
        *width: 54.1357%;
    }

    .u-sm-7-12,
    .u-sm-14-24 {
        width: 58.3333%;
        *width: 58.3023%;
    }

    .u-sm-3-5 {
        width: 60%;
        *width: 59.9690%;
    }

    .u-sm-5-8,
    .u-sm-15-24 {
        width: 62.5000%;
        *width: 62.4690%;
    }

    .u-sm-2-3,
    .u-sm-16-24 {
        width: 66.6667%;
        *width: 66.6357%;
    }

    .u-sm-17-24 {
        width: 70.8333%;
        *width: 70.8023%;
    }

    .u-sm-3-4,
    .u-sm-18-24 {
        width: 75%;
        *width: 74.9690%;
    }

    .u-sm-19-24 {
        width: 79.1667%;
        *width: 79.1357%;
    }

    .u-sm-4-5 {
        width: 80%;
        *width: 79.9690%;
    }

    .u-sm-5-6,
    .u-sm-20-24 {
        width: 83.3333%;
        *width: 83.3023%;
    }

    .u-sm-7-8,
    .u-sm-21-24 {
        width: 87.5000%;
        *width: 87.4690%;
    }

    .u-sm-11-12,
    .u-sm-22-24 {
        width: 91.6667%;
        *width: 91.6357%;
    }

    .u-sm-23-24 {
        width: 95.8333%;
        *width: 95.8023%;
    }

    .u-sm-1,
    .u-sm-1-1,
    .u-sm-5-5,
    .u-sm-24-24 {
        width: 100%;
    }
}

@media screen and (min-width: 48em) {
    .u-md-1,
    .u-md-1-1,
    .u-md-1-2,
    .u-md-1-3,
    .u-md-2-3,
    .u-md-1-4,
    .u-md-3-4,
    .u-md-1-5,
    .u-md-2-5,
    .u-md-3-5,
    .u-md-4-5,
    .u-md-5-5,
    .u-md-1-6,
    .u-md-5-6,
    .u-md-1-8,
    .u-md-3-8,
    .u-md-5-8,
    .u-md-7-8,
    .u-md-1-12,
    .u-md-5-12,
    .u-md-7-12,
    .u-md-11-12,
    .u-md-1-24,
    .u-md-2-24,
    .u-md-3-24,
    .u-md-4-24,
    .u-md-5-24,
    .u-md-6-24,
    .u-md-7-24,
    .u-md-8-24,
    .u-md-9-24,
    .u-md-10-24,
    .u-md-11-24,
    .u-md-12-24,
    .u-md-13-24,
    .u-md-14-24,
    .u-md-15-24,
    .u-md-16-24,
    .u-md-17-24,
    .u-md-18-24,
    .u-md-19-24,
    .u-md-20-24,
    .u-md-21-24,
    .u-md-22-24,
    .u-md-23-24,
    .u-md-24-24 {
        display: inline-block;
        *display: inline;
        zoom: 1;
        letter-spacing: normal;
        word-spacing: normal;
        vertical-align: top;
        text-rendering: auto;
    }

    .u-md-1-24 {
        width: 4.1667%;
        *width: 4.1357%;
    }

    .u-md-1-12,
    .u-md-2-24 {
        width: 8.3333%;
        *width: 8.3023%;
    }

    .u-md-1-8,
    .u-md-3-24 {
        width: 12.5000%;
        *width: 12.4690%;
    }

    .u-md-1-6,
    .u-md-4-24 {
        width: 16.6667%;
        *width: 16.6357%;
    }

    .u-md-1-5 {
        width: 20%;
        *width: 19.9690%;
    }

    .u-md-5-24 {
        width: 20.8333%;
        *width: 20.8023%;
    }

    .u-md-1-4,
    .u-md-6-24 {
        width: 25%;
        *width: 24.9690%;
    }

    .u-md-7-24 {
        width: 29.1667%;
        *width: 29.1357%;
    }

    .u-md-1-3,
    .u-md-8-24 {
        width: 33.3333%;
        *width: 33.3023%;
    }

    .u-md-3-8,
    .u-md-9-24 {
        width: 37.5000%;
        *width: 37.4690%;
    }

    .u-md-2-5 {
        width: 40%;
        *width: 39.9690%;
    }

    .u-md-5-12,
    .u-md-10-24 {
        width: 41.6667%;
        *width: 41.6357%;
    }

    .u-md-11-24 {
        width: 45.8333%;
        *width: 45.8023%;
    }

    .u-md-1-2,
    .u-md-12-24 {
        width: 50%;
        *width: 49.9690%;
    }

    .u-md-13-24 {
        width: 54.1667%;
        *width: 54.1357%;
    }

    .u-md-7-12,
    .u-md-14-24 {
        width: 58.3333%;
        *width: 58.3023%;
    }

    .u-md-3-5 {
        width: 60%;
        *width: 59.9690%;
    }

    .u-md-5-8,
    .u-md-15-24 {
        width: 62.5000%;
        *width: 62.4690%;
    }

    .u-md-2-3,
    .u-md-16-24 {
        width: 66.6667%;
        *width: 66.6357%;
    }

    .u-md-17-24 {
        width: 70.8333%;
        *width: 70.8023%;
    }

    .u-md-3-4,
    .u-md-18-24 {
        width: 75%;
        *width: 74.9690%;
    }

    .u-md-19-24 {
        width: 79.1667%;
        *width: 79.1357%;
    }

    .u-md-4-5 {
        width: 80%;
        *width: 79.9690%;
    }

    .u-md-5-6,
    .u-md-20-24 {
        width: 83.3333%;
        *width: 83.3023%;
    }

    .u-md-7-8,
    .u-md-21-24 {
        width: 87.5000%;
        *width: 87.4690%;
    }

    .u-md-11-12,
    .u-md-22-24 {
        width: 91.6667%;
        *width: 91.6357%;
    }

    .u-md-23-24 {
        width: 95.8333%;
        *width: 95.8023%;
    }

    .u-md-1,
    .u-md-1-1,
    .u-md-5-5,
    .u-md-24-24 {
        width: 100%;
    }
}

@media screen and (min-width: 58em) {
    .u-lg-1,
    .u-lg-1-1,
    .u-lg-1-2,
    .u-lg-1-3,
    .u-lg-2-3,
    .u-lg-1-4,
    .u-lg-3-4,
    .u-lg-1-5,
    .u-lg-2-5,
    .u-lg-3-5,
    .u-lg-4-5,
    .u-lg-5-5,
    .u-lg-1-6,
    .u-lg-5-6,
    .u-lg-1-8,
    .u-lg-3-8,
    .u-lg-5-8,
    .u-lg-7-8,
    .u-lg-1-12,
    .u-lg-5-12,
    .u-lg-7-12,
    .u-lg-11-12,
    .u-lg-1-24,
    .u-lg-2-24,
    .u-lg-3-24,
    .u-lg-4-24,
    .u-lg-5-24,
    .u-lg-6-24,
    .u-lg-7-24,
    .u-lg-8-24,
    .u-lg-9-24,
    .u-lg-10-24,
    .u-lg-11-24,
    .u-lg-12-24,
    .u-lg-13-24,
    .u-lg-14-24,
    .u-lg-15-24,
    .u-lg-16-24,
    .u-lg-17-24,
    .u-lg-18-24,
    .u-lg-19-24,
    .u-lg-20-24,
    .u-lg-21-24,
    .u-lg-22-24,
    .u-lg-23-24,
    .u-lg-24-24 {
        display: inline-block;
        *display: inline;
        zoom: 1;
        letter-spacing: normal;
        word-spacing: normal;
        vertical-align: top;
        text-rendering: auto;
    }

    .u-lg-1-24 {
        width: 4.1667%;
        *width: 4.1357%;
    }

    .u-lg-1-12,
    .u-lg-2-24 {
        width: 8.3333%;
        *width: 8.3023%;
    }

    .u-lg-1-8,
    .u-lg-3-24 {
        width: 12.5000%;
        *width: 12.4690%;
    }

    .u-lg-1-6,
    .u-lg-4-24 {
        width: 16.6667%;
        *width: 16.6357%;
    }

    .u-lg-1-5 {
        width: 20%;
        *width: 19.9690%;
    }

    .u-lg-5-24 {
        width: 20.8333%;
        *width: 20.8023%;
    }

    .u-lg-1-4,
    .u-lg-6-24 {
        width: 25%;
        *width: 24.9690%;
    }

    .u-lg-7-24 {
        width: 29.1667%;
        *width: 29.1357%;
    }

    .u-lg-1-3,
    .u-lg-8-24 {
        width: 33.3333%;
        *width: 33.3023%;
    }

    .u-lg-3-8,
    .u-lg-9-24 {
        width: 37.5000%;
        *width: 37.4690%;
    }

    .u-lg-2-5 {
        width: 40%;
        *width: 39.9690%;
    }

    .u-lg-5-12,
    .u-lg-10-24 {
        width: 41.6667%;
        *width: 41.6357%;
    }

    .u-lg-11-24 {
        width: 45.8333%;
        *width: 45.8023%;
    }

    .u-lg-1-2,
    .u-lg-12-24 {
        width: 50%;
        *width: 49.9690%;
    }

    .u-lg-13-24 {
        width: 54.1667%;
        *width: 54.1357%;
    }

    .u-lg-7-12,
    .u-lg-14-24 {
        width: 58.3333%;
        *width: 58.3023%;
    }

    .u-lg-3-5 {
        width: 60%;
        *width: 59.9690%;
    }

    .u-lg-5-8,
    .u-lg-15-24 {
        width: 62.5000%;
        *width: 62.4690%;
    }

    .u-lg-2-3,
    .u-lg-16-24 {
        width: 66.6667%;
        *width: 66.6357%;
    }

    .u-lg-17-24 {
        width: 70.8333%;
        *width: 70.8023%;
    }

    .u-lg-3-4,
    .u-lg-18-24 {
        width: 75%;
        *width: 74.9690%;
    }

    .u-lg-19-24 {
        width: 79.1667%;
        *width: 79.1357%;
    }

    .u-lg-4-5 {
        width: 80%;
        *width: 79.9690%;
    }

    .u-lg-5-6,
    .u-lg-20-24 {
        width: 83.3333%;
        *width: 83.3023%;
    }

    .u-lg-7-8,
    .u-lg-21-24 {
        width: 87.5000%;
        *width: 87.4690%;
    }

    .u-lg-11-12,
    .u-lg-22-24 {
        width: 91.6667%;
        *width: 91.6357%;
    }

    .u-lg-23-24 {
        width: 95.8333%;
        *width: 95.8023%;
    }

    .u-lg-1,
    .u-lg-1-1,
    .u-lg-5-5,
    .u-lg-24-24 {
        width: 100%;
    }
}

@media screen and (min-width: 75em) {
    .u-xl-1,
    .u-xl-1-1,
    .u-xl-1-2,
    .u-xl-1-3,
    .u-xl-2-3,
    .u-xl-1-4,
    .u-xl-3-4,
    .u-xl-1-5,
    .u-xl-2-5,
    .u-xl-3-5,
    .u-xl-4-5,
    .u-xl-5-5,
    .u-xl-1-6,
    .u-xl-5-6,
    .u-xl-1-8,
    .u-xl-3-8,
    .u-xl-5-8,
    .u-xl-7-8,
    .u-xl-1-12,
    .u-xl-5-12,
    .u-xl-7-12,
    .u-xl-11-12,
    .u-xl-1-24,
    .u-xl-2-24,
    .u-xl-3-24,
    .u-xl-4-24,
    .u-xl-5-24,
    .u-xl-6-24,
    .u-xl-7-24,
    .u-xl-8-24,
    .u-xl-9-24,
    .u-xl-10-24,
    .u-xl-11-24,
    .u-xl-12-24,
    .u-xl-13-24,
    .u-xl-14-24,
    .u-xl-15-24,
    .u-xl-16-24,
    .u-xl-17-24,
    .u-xl-18-24,
    .u-xl-19-24,
    .u-xl-20-24,
    .u-xl-21-24,
    .u-xl-22-24,
    .u-xl-23-24,
    .u-xl-24-24 {
        display: inline-block;
        *display: inline;
        zoom: 1;
        letter-spacing: normal;
        word-spacing: normal;
        vertical-align: top;
        text-rendering: auto;
    }

    .u-xl-1-24 {
        width: 4.1667%;
        *width: 4.1357%;
    }

    .u-xl-1-12,
    .u-xl-2-24 {
        width: 8.3333%;
        *width: 8.3023%;
    }

    .u-xl-1-8,
    .u-xl-3-24 {
        width: 12.5000%;
        *width: 12.4690%;
    }

    .u-xl-1-6,
    .u-xl-4-24 {
        width: 16.6667%;
        *width: 16.6357%;
    }

    .u-xl-1-5 {
        width: 20%;
        *width: 19.9690%;
    }

    .u-xl-5-24 {
        width: 20.8333%;
        *width: 20.8023%;
    }

    .u-xl-1-4,
    .u-xl-6-24 {
        width: 25%;
        *width: 24.9690%;
    }

    .u-xl-7-24 {
        width: 29.1667%;
        *width: 29.1357%;
    }

    .u-xl-1-3,
    .u-xl-8-24 {
        width: 33.3333%;
        *width: 33.3023%;
    }

    .u-xl-3-8,
    .u-xl-9-24 {
        width: 37.5000%;
        *width: 37.4690%;
    }

    .u-xl-2-5 {
        width: 40%;
        *width: 39.9690%;
    }

    .u-xl-5-12,
    .u-xl-10-24 {
        width: 41.6667%;
        *width: 41.6357%;
    }

    .u-xl-11-24 {
        width: 45.8333%;
        *width: 45.8023%;
    }

    .u-xl-1-2,
    .u-xl-12-24 {
        width: 50%;
        *width: 49.9690%;
    }

    .u-xl-13-24 {
        width: 54.1667%;
        *width: 54.1357%;
    }

    .u-xl-7-12,
    .u-xl-14-24 {
        width: 58.3333%;
        *width: 58.3023%;
    }

    .u-xl-3-5 {
        width: 60%;
        *width: 59.9690%;
    }

    .u-xl-5-8,
    .u-xl-15-24 {
        width: 62.5000%;
        *width: 62.4690%;
    }

    .u-xl-2-3,
    .u-xl-16-24 {
        width: 66.6667%;
        *width: 66.6357%;
    }

    .u-xl-17-24 {
        width: 70.8333%;
        *width: 70.8023%;
    }

    .u-xl-3-4,
    .u-xl-18-24 {
        width: 75%;
        *width: 74.9690%;
    }

    .u-xl-19-24 {
        width: 79.1667%;
        *width: 79.1357%;
    }

    .u-xl-4-5 {
        width: 80%;
        *width: 79.9690%;
    }

    .u-xl-5-6,
    .u-xl-20-24 {
        width: 83.3333%;
        *width: 83.3023%;
    }

    .u-xl-7-8,
    .u-xl-21-24 {
        width: 87.5000%;
        *width: 87.4690%;
    }

    .u-xl-11-12,
    .u-xl-22-24 {
        width: 91.6667%;
        *width: 91.6357%;
    }

    .u-xl-23-24 {
        width: 95.8333%;
        *width: 95.8023%;
    }

    .u-xl-1,
    .u-xl-1-1,
    .u-xl-5-5,
    .u-xl-24-24 {
        width: 100%;
    }
}
* {
    -webkit-box-sizing: border-box;
       -moz-box-sizing: border-box;
            box-sizing: border-box;
}

*:before,
*:after {
    -webkit-box-sizing: border-box;
       -moz-box-sizing: border-box;
            box-sizing: border-box;
}

html, button, input, select, textarea,
.pure-g [class *= "pure-u"] {
    font-family: "proxima-nova", sans-serif;
}


/* --------------------------
 * Element Styles
 * --------------------------
*/

body {
    min-width: 320px;
    color: #777;
    line-height: 1.6;
}

h1, h2, h3, h4, h5, h6 {
    font-weight: bold;
    color: rgb(75, 75, 75);
}
h3 {
    font-size: 1.25em;
}
h4 {
    font-size: 1.125em;
}

a {
    color: #3b8bba; /* block-background-text-normal */
    text-decoration: none;
}

a:visited {
    color: #265778; /* block-normal-text-normal */
}

dt {
    font-weight: bold;
}
dd {
    margin: 0 0 10px 0;
}

aside {
    background: #1f8dd6; /* same color as selected state on site menu */
    padding: 0.3em 1em;
    border-radius: 3px;
    color: #fff;
}
    aside a, aside a:visited {
        color: rgb(169, 226, 255);
    }


/* --------------------------
 * Layout Styles
 * --------------------------
*/

/* Navigation Push Styles */
#layout {
    position: relative;
    padding-left: 0;
}
    #layout.active {
        position: relative;
        left: 160px;
    }
        #layout.active #menu {
            left: 160px;
            width: 160px;
        }

/* Apply the .box class on the immediate parent of any grid element (pure-u-*) to apply some padding. */
.l-box {
    padding: 1em;
}

.l-wrap {
    margin-left: auto;
    margin-right: auto;
}
.content .l-wrap {
    margin-left: -1em;
    margin-right: -1em;
}


/* --------------------------
 * Header Module Styles
 * --------------------------
*/

.header {
     font-family: "omnes-pro", sans-serif;
     max-width: 768px;
     margin: 0 auto;
     padding: 1em;
     text-align: center;
     border-bottom: 1px solid #eee;
     background: #fff;
 }
    .header h1 {
        font-size: 300%;
        font-weight: 100;
        margin: 0;
    }
     .header h2 {
        font-size: 125%;
        font-weight: 100;
        line-height: 1.5;
        margin: 0;
        color: #666;
    }


 /* --------------------------
  * Content Module Styles
  * --------------------------
 */

/* The content div is placed as a wrapper around all the docs */
.content {
    margin-left: auto;
    margin-right: auto;
    padding-left: 1em;
    padding-right: 1em;
    max-width: 768px;
}

    .content .content-subhead {
        margin: 2em 0 1em 0;
        font-weight: 300;
        color: #888;
        position: relative;
    }

    .content .content-spaced {
        line-height: 1.8;
    }

    .content .content-quote {
        font-family: "Georgia", serif;
        color: #666;
        font-style: italic;
        line-height: 1.8;
        border-left: 5px solid #ddd;
        padding-left: 1.5em;
    }

    .content-link {
        position: absolute;
        top: 0;
        right: 0;
        display: block;
        height: 100%;
        width: 20px;
        background: transparent url('/static/djangomaster/img/link-icon.png') no-repeat center center;
        background-size: 20px 20px;
    }

    @media (-webkit-min-device-pixel-ratio: 2), (min-resolution: 2dppx) {
        .content-link {
            background-image: url('/static/djangomaster/img/link-icon@2x.png');
        }
    }


/* --------------------------
 * Code Styles
 * --------------------------
*/

pre,
code {
    font-family: Consolas, 'Liberation Mono', Courier, monospace;
    color: #333;
    background: rgb(250, 250, 250);
}

code {
    padding: 0.2em 0.4em;
    white-space: nowrap;
}
.content p code {
    font-size: 90%;
}

.code {
    margin-left: -1em;
    margin-right: -1em;
    padding: 1em;
    border: 1px solid #eee;
    border-left-width: 0;
    border-right-width: 0;
    overflow-x: auto;
    -webkit-overflow-scrolling: touch;
}
.code code {
    font-size: 95%;
    white-space: pre;
    word-wrap: normal;
    padding: 0;
    background: none;
}
.code-wrap code {
    white-space: pre-wrap;
    word-wrap: break-word;
}

/* --------------------------
 * Footer Module Styles
 * --------------------------
*/

.footer {
    font-size: 87.5%;
    border-top: 1px solid #eee;
    margin-top: 3.4286em;
    padding: 1.1429em;
    background: rgb(250, 250, 250);
}

.legal {
    line-height: 1.6;
    text-align: center;
    margin: 0 auto;
}

    .legal-license {
        margin-top: 0;
    }
    .legal-links {
        list-style: none;
        padding: 0;
        margin-bottom: 0;
    }
    .legal-copyright {
        margin-top: 0;
        margin-bottom: 0;
    }


/* --------------------------
 * Main Navigation Bar Styles
 * --------------------------
*/

/* Add transition to containers so they can push in and out */
#layout,
#menu,
.menu-link {
    -webkit-transition: all 0.2s ease-out;
    -moz-transition: all 0.2s ease-out;
    -ms-transition: all 0.2s ease-out;
    -o-transition: all 0.2s ease-out;
    transition: all 0.2s ease-out;
}

#layout.active .menu-link {
    left: 160px;
}

#menu {
    margin-left: -160px; /* "#menu" width */
    width: 160px;
    position: fixed;
    top: 0;
    left: 0;
    bottom: 0;
    z-index: 1000; /* so the menu or its navicon stays above all content */
    background: #191818;
    overflow-y: auto;
    -webkit-overflow-scrolling: touch;
}
    #menu a {
        color: #999;
        border: none;
        white-space: normal;
        padding: 0.625em 1em;
    }

    #menu .pure-menu-open {
        background: transparent;
        border: 0;
    }

    #menu .pure-menu ul {
        border: none;
        background: transparent;
    }

    #menu .pure-menu ul,
    #menu .pure-menu .menu-item-divided {
        border-top: 1px solid #333;
    }

        #menu .pure-menu li a:hover,
        #menu .pure-menu li a:focus {
            background: #333;
        }

    .menu-link {
        position: fixed;
        display: block; /* show this only on small screens */
        top: 0;
        left: 0; /* "#menu width" */
        background: #000;
        background: rgba(0,0,0,0.7);
        font-size: 11px; /* change this value to increase/decrease button size */
        z-index: 10;
        width: 4em;
        height: 4em;
        padding: 1em;
    }

        .menu-link:hover,
        .menu-link:focus {
            background: #000;
        }

        .menu-link span {
            position: relative;
            display: block;
            margin-top: 0.9em;
        }

        .menu-link span,
        .menu-link span:before,
        .menu-link span:after {
            background-color: #fff;
            width: 100%;
            height: .2em;
            -webkit-transition: all 0.4s;
               -moz-transition: all 0.4s;
                -ms-transition: all 0.4s;
                 -o-transition: all 0.4s;
                    transition: all 0.4s;
        }

            .menu-link span:before,
            .menu-link span:after {
                position: absolute;
                top: -.55em;
                content: " ";
            }

            .menu-link span:after {
                top: .55em;
            }

        .menu-link.active span {
            background: transparent;
        }

            .menu-link.active span:before {
                -webkit-transform: rotate(45deg) translate(.5em, .4em);
                   -moz-transform: rotate(45deg) translate(.5em, .4em);
                    -ms-transform: rotate(45deg) translate(.5em, .4em);
                     -o-transform: rotate(45deg) translate(.5em, .4em);
                        transform: rotate(45deg) translate(.5em, .4em);
            }

            .menu-link.active span:after {
                -webkit-transform: rotate(-45deg) translate(.4em, -.3em);
                   -moz-transform: rotate(-45deg) translate(.4em, -.3em);
                    -ms-transform: rotate(-45deg) translate(.4em, -.3em);
                     -o-transform: rotate(-45deg) translate(.4em, -.3em);
                        transform: rotate(-45deg) translate(.4em, -.3em);
            }

    #menu .pure-menu-heading {
        font-size: 125%;
        font-weight: 300;
        letter-spacing: 0.1em;
        color: #fff;
        margin-top: 0;
        padding: 0.5em 0.8em;
    }
    #menu .pure-menu-heading:hover,
    #menu .pure-menu-heading:focus {
        color: #999;
    }

    #menu .pure-menu-selected {
        background: #1f8dd6;
    }

        #menu .pure-menu-selected a {
            color: #fff;
        }

        #menu li.pure-menu-selected a:hover,
        #menu li.pure-menu-selected a:focus {
            background: none;
        }



/* ---------------------
 * Smaller Module Styles
 * ---------------------
*/

.pure-img-responsive {
    max-width: 100%;
    height: auto;
}

.pure-paginator .pure-button {
    -webkit-box-sizing: content-box;
    -moz-box-sizing: content-box;
    box-sizing: content-box;
}

.pure-button {
    font-family: inherit;
}
a.pure-button-primary {
    color: white;
}


/* green call to action button class */
.notice {
    background-color: #61B842;
    color: white;
}

.muted {
    color: #ccc;
}



/* -------------
 * Table Styles
 * -------------
*/

.pure-table th,
.pure-table td {
    padding: 0.5em 1em;
}

.table-responsive {
    margin-left: -1em;
    margin-right: -1em;
    overflow-x: auto;
    -webkit-overflow-scrolling: touch;
    margin-bottom: 1em;
}
.table-responsive table {
    width: 100%;
    min-width: 35.5em;
    border-left-width: 0;
    border-right-width: 0;
}

.table-responsive .mq-table {
    width: 100%;
    min-width: 44em;
}
.mq-table th.highlight {
    background-color: rgb(255, 234, 133);
}
.mq-table td.highlight {
    background-color: rgb(255, 250, 229);
}
.mq-table th.highlight code,
.mq-table td.highlight code {
    background: rgb(255, 255, 243);
}
.mq-table-mq code {
    font-size: 0.875em;
}

/* ----------------------------
 * Example for full-width Grids
 * ----------------------------
*/

.grids-example {
    background: rgb(250, 250, 250);
    margin: 2em auto;
    border-top: 1px solid #ddd;
    border-bottom: 1px solid #ddd;
}

/* --------------------------
 * State Rules
 * --------------------------
*/


.is-code-full {
    text-align: center;
}
.is-code-full .code {
    margin-left: auto;
    margin-right: auto;
}


/* --------------------------
 * Responsive Styles
 * --------------------------
*/

@media screen and (min-width: 35.5em) {

    .legal-license {
        text-align: left;
        margin: 0;
    }
    .legal-copyright,
    .legal-links,
    .legal-links li {
        text-align: right;
        margin: 0;
    }

}

@media screen and (min-width: 48em) {

    .l-wrap,
    .l-wrap .content {
        padding-left: 1em;
        padding-right: 1em;
    }
    .content .l-wrap {
        margin-left: -2em;
        margin-right: -2em;
    }

    .header,
    .content {
        padding-left: 2em;
        padding-right: 2em;
    }

    .header h1 {
        font-size: 350%;
    }
    .header h2 {
        font-size: 150%;
    }

    .content p {
        font-size: 1.125em;
    }

    .code {
        margin-left: auto;
        margin-right: auto;
        border-left-width: 1px;
        border-right-width: 1px;
    }

    .table-responsive {
        margin-left: auto;
        margin-right: auto;
    }
    .table-responsive table {
        border-left-width: 1px;
        border-right-width: 1px;
    }

}

@media (min-width: 58em) {

    #layout {
        padding-left: 160px; /* left col width "#menu" */
        left: 0;
    }
    #menu {
        left: 160px;
    }
    .menu-link {
        position: fixed;
        left: 160px;
        display: none;
    }
    #layout.active .menu-link {
        left: 160px;
    }

}

.grids-unit {
    margin: 0.25em 0;
    padding-left: 4.5em;
}
.grids-unit-width {
    width: 4em;
    margin-left: -4.5em;
    padding-right: 0.5em;
    line-height: 2em;
    text-align: right;
    vertical-align: baseline;
}
.grids-unit .grids-unit-width {
    font-family: Consolas, 'Liberation Mono', Courier, monospace;
}
.grids-unit-details {
    position: relative;
    background: #fafafa
}
.grids-unit-classnames {
    position: absolute;
    left: 0.5em;
}
.grids-unit-classname {
    margin-right: 1em;
}
.grids-unit-classname code {
    background: none;
    padding: 0;
    margin: 0;
}
.grids-unit-bar {
    height: 2em;
    background: #eee;
}

/**
 * Baby Blue theme for RainbowJS
 *
 * @author tilomitra
 */

pre .comment {
    color: #999;
}

pre .tag,
pre .tag-name,
pre .support.tag-name {
    color: rgb(85, 85, 85);
}

pre .keyword,
pre .css-property,
pre .vendor-prefix,
pre .sass,
pre .class,
pre .id,
pre .css-value,
pre .entity.function,
pre .storage.function {
    font-weight: bold;
}

pre .css-property,
pre .css-value,
pre .vendor-prefix,
pre .support.namespace {
    color: #333;
}

pre .constant.numeric,
pre .keyword.unit,
pre .hex-color {
    font-weight: normal;
    color: #099;
}

pre .attribute,
pre .variable,
pre .support {
    color:  #757575; /* skinbuilder block-page-text-normal with #1f8dd6 as primary */
}

pre .string,
pre .support.value  {
    font-weight: normal;
    color: #3b8bba; /* skinbuilder block-mine-text-low with #1f8dd6 as primary */
}
